@@ -56,7 +56,8 @@ __builder__ = {
             "hidden": "application_menu_hidden",
             "fulltext": "application_menu_fulltext",
             "advanced": "application_menu_advanced",
-            "update": "application_menu_update"
+            "update": "application_menu_update",
+            "preferences": "application_menu_prefs",
         },
         # File Context Menu
         "file": {
@@ -209,6 +210,12 @@ class Window(Gtk.Window):
         search.grab_focus()
         self.keys_pressed = []
 
+        self.search_engine = None
+        self.settings = None
+
+    def on_sidebar_toggle_toggled(self, widget):
+        pass
+
     def setup_headerbar(self, chooser, search, button):
         headerbar = Gtk.HeaderBar.new()
         headerbar.set_show_close_button(True)
@@ -338,7 +345,7 @@ class Window(Gtk.Window):
         return False
 
     def on_catfish_window_size_allocate(self, widget, allocation):
-        paned =self.builder.get_named_object("window.paned")
+        paned = self.builder.get_named_object("window.paned")
         allocation = paned.get_allocation()
         self.settings.set_setting('window-height', allocation.height)
         self.settings.set_setting('window-width', allocation.width)
@@ -348,4 +355,4 @@ class Window(Gtk.Window):
     def on_catfish_window_configure_event(self, widget, event):
         pos = self.get_position()
         self.settings.set_setting('window-x', pos.root_x)
-        self.settings.set_setting('window-y', pos.root_y)
\ No newline at end of file
+        self.settings.set_setting('window-y', pos.root_y)
